pref("toolkit.defaultChromeURI", "chrome://tile/content/foo.xul");
pref("javascript.options.tracejit.chrome",  false);
pref("javascript.options.tracejit.content", false);
pref("browser.dom.window.dump.enabled", true);
